@@ -18,6 +18,8 @@
  */
 package org.apache.iceberg.spark.extensions;
 
+import static org.assertj.core.api.Assertions.assertThatThrownBy;
+
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.TimeUnit;
@@ -29,7 +31,6 @@ import org.apache.iceberg.spark.source.SimpleRecord;
 import org.apache.spark.sql.Dataset;
 import org.apache.spark.sql.Row;
 import org.apache.spark.sql.catalyst.analysis.NoSuchTableException;
-import org.assertj.core.api.Assertions;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Test;
@@ -74,13 +75,14 @@ public class TestReplaceBranch extends SparkExtensionsTestBase {
     df.writeTo(tableName).append();
     long second = table.currentSnapshot().snapshotId();
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "ALTER TABLE %s REPLACE BRANCH %s AS OF VERSION %d",
                     tableName, tagName, second))
+        .as("Cannot perform replace branch on tags")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Ref tag1 is a tag not a branch");
+        .hasMessageContaining("Ref tag1 is a tag not a branch");
   }
 
   @Test
@@ -128,13 +130,14 @@ public class TestReplaceBranch extends SparkExtensionsTestBase {
     df.writeTo(tableName).append();
     Table table = validationCatalog.loadTable(tableIdent);
 
-    Assertions.assertThatThrownBy(
+    assertThatThrownBy(
             () ->
                 sql(
                     "ALTER TABLE %s REPLACE BRANCH %s AS OF VERSION %d",
                     tableName, "someBranch", table.currentSnapshot().snapshotId()))
+        .as("Cannot perform replace branch on branch which does not exist")
         .isInstanceOf(IllegalArgumentException.class)
-        .hasMessage("Branch does not exist: someBranch");
+        .hasMessageContaining("Branch does not exist");
   }
 
   @Test
