@@ -105,8 +105,9 @@ public class TestNamespaceSQL extends SparkCatalogTestBase {
         "Table should exist", validationCatalog.tableExists(TableIdentifier.of(NS, "table")));
 
     assertThatThrownBy(() -> sql("DROP NAMESPACE %s", fullNamespace))
+        .as("Should fail if trying to delete a non-empty namespace")
         .isInstanceOf(NamespaceNotEmptyException.class)
-        .hasMessageStartingWith("Namespace db is not empty.");
+        .hasMessageContaining("Namespace db is not empty.");
 
     sql("DROP TABLE %s.table", fullNamespace);
   }
